# libbaihanupython
Módulo para exemplificar a construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de cóigo aberto(Open Source)

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.com/Dev-lucas-eduardo/libbaihanupython.svg?branch=main)](https://travis-ci.com/Dev-lucas-eduardo/libbaihanupython)
[![Updates](https://pyup.io/repos/github/Dev-lucas-eduardo/libbaihanupython/shield.svg)](https://pyup.io/repos/github/Dev-lucas-eduardo/libbaihanupython/)
[![Python 3](https://pyup.io/repos/github/Dev-lucas-eduardo/libbaihanupython/python-3-shield.svg)](https://pyup.io/repos/github/Dev-lucas-eduardo/libbaihanupython/)

Suportada a versão 3 de Python

Para instalar no Windows:

```console
py -3 -m venv .venv
.venv\Scripts\activate
pip install -r requirements-dev.txt
```

Para instalar no Linux:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualiade do código:

```console
flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
